import * as io from 'io-ts';
import * as iot from 'io-ts-types';
export declare class NgxGist implements Gist {
    constructor(args: Gist & Pick<NgxGist, 'languageOverride'>);
    /** Core gist properties */
    readonly comments: number;
    readonly comments_url: string;
    readonly commits_url: string;
    readonly created_at: Date;
    readonly description: string;
    readonly files: io.TypeOf<typeof gistFilesCodec>;
    readonly forks: unknown[];
    readonly forks_url: string;
    readonly git_pull_url: string;
    readonly git_push_url: string;
    readonly history: Array<io.TypeOf<typeof gistHistoryCodec>>;
    readonly html_url: string;
    readonly id: string;
    readonly node_id: string;
    readonly owner?: io.TypeOf<typeof gitHubUserCodec>;
    readonly public: boolean;
    readonly truncated: boolean;
    readonly updated_at: Date;
    readonly url: string;
    readonly user?: unknown;
    /** Additional properties */
    readonly highlightedFiles: HighlightedFiles;
    readonly languageOverride?: string;
    /**
     * Create a local, static gist object. Do not use this for fetched data.
     * Used for creating and displaying local code samples.
     *
     * Use `deserialize` sibling function for remote "unknown" responses.
     *
     * @param args Minimally necessary paramaters for displaying local code.
     * @returns A 'partial' model in which unnecessary fields are dummny data.
     */
    static create(args: {
        files: Files;
    } & Partial<Pick<Gist, 'created_at' | 'description'>> & // Required // Optional
    Pick<NgxGist, 'languageOverride'>): NgxGist;
    /**
     * Deserialize and decode fetched/unknown data into the full model.
     *
     * @param value Unknown value, but expects a full model either by object or JSON string.
     * @returns Either the full model or null if deserialization fails.
     */
    static deserialize(value: unknown): NgxGist | null;
}
declare type Files = Array<Pick<GistFilesContent, 'content' | 'filename'>>;
declare type HighlightedFiles = Array<GistFilesContent & HighlightedContent>;
interface HighlightedContent {
    highlightedContent: string;
}
declare const gitHubUserCodec: io.ReadonlyC<io.TypeC<{
    avatar_url: io.StringC;
    events_url: io.StringC;
    followers_url: io.StringC;
    following_url: io.StringC;
    gists_url: io.StringC;
    gravatar_id: io.StringC;
    html_url: io.StringC;
    id: io.NumberC;
    login: io.StringC;
    node_id: io.StringC;
    organizations_url: io.StringC;
    received_events_url: io.StringC;
    repos_url: io.StringC;
    site_admin: io.BooleanC;
    starred_url: io.StringC;
    subscriptions_url: io.StringC;
    type: io.StringC;
    url: io.StringC;
}>>;
declare const gistHistoryCodec: io.ReadonlyC<io.TypeC<{
    change_status: io.ReadonlyC<io.TypeC<{
        additions: io.NumberC;
        deletions: io.NumberC;
        total: io.NumberC;
    }>>;
    committed_at: io.UnionC<[iot.DateC, io.StringC]>;
    url: io.StringC;
    user: io.ReadonlyC<io.TypeC<{
        avatar_url: io.StringC;
        events_url: io.StringC;
        followers_url: io.StringC;
        following_url: io.StringC;
        gists_url: io.StringC;
        gravatar_id: io.StringC;
        html_url: io.StringC;
        id: io.NumberC;
        login: io.StringC;
        node_id: io.StringC;
        organizations_url: io.StringC;
        received_events_url: io.StringC;
        repos_url: io.StringC;
        site_admin: io.BooleanC;
        starred_url: io.StringC;
        subscriptions_url: io.StringC;
        type: io.StringC;
        url: io.StringC;
    }>>;
    version: io.StringC;
}>>;
declare const gistFilesContent: io.TypeC<{
    content: io.StringC;
    filename: io.StringC;
    language: io.StringC;
    raw_url: io.StringC;
    size: io.NumberC;
    truncated: io.BooleanC;
    type: io.StringC;
}>;
declare type GistFilesContent = io.TypeOf<typeof gistFilesContent>;
declare const gistFilesCodec: io.RecordC<io.StringC, io.TypeC<{
    content: io.StringC;
    filename: io.StringC;
    language: io.StringC;
    raw_url: io.StringC;
    size: io.NumberC;
    truncated: io.BooleanC;
    type: io.StringC;
}>>;
export declare const gistCodec: io.ReadonlyC<io.IntersectionC<[io.TypeC<{
    comments: io.NumberC;
    comments_url: io.StringC;
    commits_url: io.StringC;
    created_at: io.UnionC<[iot.DateC, io.StringC]>;
    description: io.StringC;
    files: io.RecordC<io.StringC, io.TypeC<{
        content: io.StringC;
        filename: io.StringC;
        language: io.StringC;
        raw_url: io.StringC;
        size: io.NumberC;
        truncated: io.BooleanC;
        type: io.StringC;
    }>>;
    forks: io.UnknownArrayC;
    forks_url: io.StringC;
    git_pull_url: io.StringC;
    git_push_url: io.StringC;
    history: io.ArrayC<io.ReadonlyC<io.TypeC<{
        change_status: io.ReadonlyC<io.TypeC<{
            additions: io.NumberC;
            deletions: io.NumberC;
            total: io.NumberC;
        }>>;
        committed_at: io.UnionC<[iot.DateC, io.StringC]>;
        url: io.StringC;
        user: io.ReadonlyC<io.TypeC<{
            avatar_url: io.StringC;
            events_url: io.StringC;
            followers_url: io.StringC;
            following_url: io.StringC;
            gists_url: io.StringC;
            gravatar_id: io.StringC;
            html_url: io.StringC;
            id: io.NumberC;
            login: io.StringC;
            node_id: io.StringC;
            organizations_url: io.StringC;
            received_events_url: io.StringC;
            repos_url: io.StringC;
            site_admin: io.BooleanC;
            starred_url: io.StringC;
            subscriptions_url: io.StringC;
            type: io.StringC;
            url: io.StringC;
        }>>;
        version: io.StringC;
    }>>>;
    html_url: io.StringC;
    id: io.StringC;
    node_id: io.StringC;
    public: io.BooleanC;
    truncated: io.BooleanC;
    updated_at: io.UnionC<[iot.DateC, io.StringC]>;
    url: io.StringC;
}>, io.PartialC<{
    owner: io.UnionC<[io.ReadonlyC<io.TypeC<{
        avatar_url: io.StringC;
        events_url: io.StringC;
        followers_url: io.StringC;
        following_url: io.StringC;
        gists_url: io.StringC;
        gravatar_id: io.StringC;
        html_url: io.StringC;
        id: io.NumberC;
        login: io.StringC;
        node_id: io.StringC;
        organizations_url: io.StringC;
        received_events_url: io.StringC;
        repos_url: io.StringC;
        site_admin: io.BooleanC;
        starred_url: io.StringC;
        subscriptions_url: io.StringC;
        type: io.StringC;
        url: io.StringC;
    }>>, io.UndefinedC]>;
    user: io.UnionC<[io.UnknownC, io.NullC, io.UndefinedC]>;
}>]>>;
/**
 * Official Gist object
 * https://docs.github.com/en/rest/gists
 */
declare type Gist = io.TypeOf<typeof gistCodec>;
export {};
