import * as io from 'io-ts';
/**
 * Validate that the value is a string that is non-empty.
 */
export declare function isNonEmptyString(value: unknown): value is string;
export declare function isStringArray(value: unknown): value is string[];
export declare function isNonEmptyValue<T>(value: T): value is NonNullable<T>;
/**
 * Decode by parsing json object of string value.
 */
export declare const parsedJsonFromStringCodec: io.Type<unknown, string, string>;
/**
 * Decode value using a passed codec and its' decoder.
 *
 * @param codec Codec used to decode value.
 *
 * @typeParam A - Static type (expected)
 * @typeParam O - Encode outputs of type
 * @typeParam I - Decode input of type
 *
 * @returns The decoeded value or null if an error occurs.
 */
export declare function decodeValueElseNull<A, I, O = unknown>(codec: io.Type<A, O, I>): (value: I) => A | null;
